@@ -31,4 +31,4 @@ if __name__ == '__main__':
     chain = get_simple_chain(log=log)
 
     log.info('start fitting chain')
-    chain.fit(train_data, use_cache=False, verbose=True)
+    chain.fit(train_data, use_cache=False)
