@@ -61,7 +61,13 @@ class Data:
             features = data_array[1:].T
             target = None
 
-        features = ImputationStrategy().fit(features).apply(features)
+        if features.shape[1] == 0 and task.task_type == TaskTypesEnum.ts_forecasting:
+            features = None
+
+        features = _process_empty_features_for_task(features, task)
+
+        if features is not None:
+            features = ImputationStrategy().fit(features).apply(features)
 
         return InputData(idx=idx, features=features, target=target, task=task, data_type=data_type)
 
@@ -163,7 +169,7 @@ class InputData(Data):
 @dataclass
 class OutputData(Data):
     """
-    Data type for data predicted in the node
+    Data type for data prediction in the node
     """
     predict: np.array = None
 
@@ -264,3 +270,11 @@ def _combine_datasets_common(outputs: List[OutputData]):
             for i in range(number_of_variables_in_prediction):
                 features.append(elem.predict[:, i])
     return features
+
+
+def _process_empty_features_for_task(features, task: Task):
+    if (features is not None and
+            features.shape[1] == 0 and
+            task.task_type == TaskTypesEnum.ts_forecasting):
+        return None
+    return features
